@@ -1,8 +1,11 @@
+"""
+Init imports
+"""
 from .binary_uuid import BinaryUUID
 from .func_date import convert_date_to_timestamp, get_timestamp_now, convert_timestamp_to_date
 from .prepare_json_response import prepare_json_response
 from .generic_pagination import PaginationSchema
 from .validation_utils import validate_generic_form
-from .abstract_model import BaseModal
+from .abstract_model import BaseModel
 from .model_utils import JsonEncodeDict, generic_get_serialize_data, TimestampField
 from .view_utils import ViewGeneralMethods
